gcode::core

Enum TokenType

pub enum TokenType {
Show 13 variants Letter, G, M, T, Percent, Number, Comment, Slash, MinusSign, PlusSign, Newline, Unknown, Eof,
}
Lexer token kind. Used by the parser and in Diagnostics::emit_unexpected to report what was expected.

Variants



Letter

Single alphabetic character that is not G, M, or T (e.g. N, O, X).



G

G code letter (case-insensitive in source).



M

M code letter (case-insensitive in source).



T

T code letter (case-insensitive in source).



Percent

Program delimiter % (RS-274 / ISO 6983).



Number

Numeric literal.



Comment

Comment (semicolon or parentheses).



Slash

A / is used to indicate a deleted block.



MinusSign

Minus sign.



PlusSign

Plus sign.



Newline

Newline.



Unknown

Unrecognised token.



Eof

Virtual: expected end of input (no more tokens).

Implementations

Source

impl TokenType

pub const fn as_str(self) -> &'static str

Get the human-friendly name for this token type.